TI OMAP3: SDP3430 FIX NET_MULTI Warning

Enable the NET MULTI option and remove build warning

Tested: SDP3430

Signed-off-by: Nishanth Menon <nm@ti.com>
Signed-off-by: Ben Warren <biggerbadderben@gmail.com>
diff --git a/include/configs/omap3_sdp3430.h b/include/configs/omap3_sdp3430.h
index d91c8ff..fa2ad53 100644
--- a/include/configs/omap3_sdp3430.h
+++ b/include/configs/omap3_sdp3430.h
@@ -203,7 +203,8 @@
  */
 #if defined(CONFIG_CMD_NET)
 
-#define CONFIG_DRIVER_LAN91C96
+#define CONFIG_NET_MULTI
+#define CONFIG_LAN91C96
 #define CONFIG_LAN91C96_BASE	DEBUG_BASE
 #define CONFIG_LAN91C96_EXT_PHY
diff --git a/board/ti/sdp3430/sdp.c b/board/ti/sdp3430/sdp.c
index 40cf26f..0d8e20d 100644
--- a/board/ti/sdp3430/sdp.c
+++ b/board/ti/sdp3430/sdp.c
@@ -22,6 +22,7 @@
  * MA 02111-1307 USA
  */
 #include <common.h>
+#include <netdev.h>
 #include <twl4030.h>
 #include <asm/io.h>
 #include <asm/arch/mux.h>
@@ -125,12 +126,13 @@
 #define ETH_CONTROL_REG		(CONFIG_LAN91C96_BASE + 0x30b)
 
 /**
  * @brief ether_init Take the Ethernet controller out of reset and wait
  * for the EEPROM load to complete.
  */
-static void ether_init(void)
+int board_eth_init(bd_t *bis)
 {
-#ifdef CONFIG_DRIVER_LAN91C96
+	int rc = 0;
+#ifdef CONFIG_LAN91C96
 	int cnt = 20;
 
 	writew(0x0, LAN_RESET_REGISTER);
@@ -155,10 +157,11 @@
 
 	writeb(readb(ETH_CONTROL_REG) & ~0x1, ETH_CONTROL_REG);
 	udelay(1000);
+	rc = lan91c96_initialize(0, CONFIG_LAN91C96_BASE);
 reset_err_out:
-	return;
 
 #endif
+	return rc;
 }
 
 /**
@@ -187,7 +190,6 @@
 	 *   VSIM  - off (init, variable) for MMC1.DAT[3..7], SIM
 	 *   VPLL2 - 1.8V
 	 */
-	ether_init();
 
 	return 0;
 }
@@ -125,12 +126,13 @@
 
 /**
- * @brief ether_init Take the Ethernet controller out of reset and wait
+ * @brief board_eth_init Take the Ethernet controller out of reset and wait
  * for the EEPROM load to complete.
  */